import orca_rs


def test_parse_tddft():
    a = orca_rs.parse_tddft("./tests/data/ch2o_soc_tddft.out")
    print(a)

def test_parse_casscf():
    a = orca_rs.parse_casscf("./tests/data/product_sa_casscf_v8_5a897afa.out")
    print(a)



from typing import TypedDict

class Contribution(TypedDict):
    atom_nr: int
    element: str
    orbital_type: str
    contribution: float

class Orbital(TypedDict):
    orbital_nr: int
    energy: float
    occupation: float
    contributions: list[Contribution]


class CASSCFOutput(TypedDict):
    orbital_compositions: list[Orbital]



from orca_rs.outputs.casscf import CASSCFOutput
from orca_rs.outputs.tddft import TDDFTOutput

def parse_tddft(filename: str) -> TDDFTOutput:
    """Parse orca output file"""


def parse_casscf(filename: str) -> CASSCFOutput:
    """Parse orca output file"""
